Module which provides a macro that generates special code for a duration filter.
the format is governed by section 4.1.2 of RFC 5321: https://www.rfc-editor.org/rfc/rfc5321.txt
Summary
Functions
Creates a NimbleParsec parser ~email/1.
Functions
Creates a NimbleParsec parser ~email/1.
This function returns {:ok, ...} if the passed string is a valid email, or
{:error, reason, ...} if it is not. See NimbleParsec for more
information on the return tuples.
The function will only be created once per module, and it is safe to call the macro more than once.
Options:
:name(atom): the name of the function to create. Defaults to:"~email"