Exonerate.Formats.IdnEmail (exonerate v1.2.1)

Copy Markdown View Source

Module which provides a macro that generates special code for an idn-email filter. This is an email address with internationalization support.

the format is governed by section 3.3 of RFC 6531: https://www.rfc-editor.org/rfc/rfc6531.txt

Summary

Functions

Creates a NimbleParsec parser ~idn-email/1.

Functions

filter(opts \\ [])

(macro)

Creates a NimbleParsec parser ~idn-email/1.

This function returns {:ok, ...} if the passed string is a valid idn-email, or {:error, reason, ...} if it is not. See NimbleParsec for more information on the return tuples.

The function will only be created once per module, and it is safe to call the macro more than once.

Options:

  • :name (atom): the name of the function to create. Defaults to :"~idn-email"