Exonerate.Formats.JsonPointer (exonerate v1.2.1)

Copy Markdown View Source

Module which provides a macro that generates special code for a json pointer filter.

the format is governed by Section 3 of RFC 6901: https://www.rfc-editor.org/rfc/rfc6901.txt

Summary

Functions

Creates a NimbleParsec parser ~json-pointer/1.

Functions

filter(opts \\ [])

(macro)

Creates a NimbleParsec parser ~json-pointer/1.

This function returns {:ok, ...} if the passed string is a valid json pointer, or {:error, reason, ...} if it is not. See NimbleParsec for more information on the return tuples.

The function will only be created once per module, and it is safe to call the macro more than once.

Options:

  • :name (atom): the name of the function to create. Defaults to :"~json-pointer"