Exonerate.Formats.Regex (exonerate v1.2.1)

Copy Markdown View Source

Module which provides a macro that generates special code for an json pointer filter.

the format is governed by the ECMA-262 standard: https://www.ecma-international.org/publications-and-standards/standards/ecma-262/

Summary

Functions

Creates a NimbleParsec parser ~regex/1.

Functions

filter(opts \\ [])

(macro)

Creates a NimbleParsec parser ~regex/1.

This function returns {:ok, ...} if the passed string is a valid regex, or {:error, reason, ...} if it is not. See NimbleParsec for more information on the return tuples.

The function will only be created once per module, and it is safe to call the macro more than once.

Options:

  • :name (atom): the name of the function to create. Defaults to :"~regex"