Exonerate.Formats.Uri (exonerate v1.2.1)

Copy Markdown View Source

Module which provides a macro that generates special code for a uri. This is an absolute uri.

If you require a relative uri, use Exonerate.Formats.UriReference.

the format is governed by appendix A of RFC 3986: https://www.rfc-editor.org/rfc/rfc3986.txt

Summary

Functions

Creates a NimbleParsec parser ~uri/1.

Functions

filter(opts \\ [])

(macro)

Creates a NimbleParsec parser ~uri/1.

This function returns {:ok, ...} if the passed string is a valid uri, or {:error, reason, ...} if it is not. See NimbleParsec for more information on the return tuples.

The function will only be created once per module, and it is safe to call the macro more than once.

Options:

  • :name (atom): the name of the function to create. Defaults to :"~uri"