Exonerate.Remote (exonerate v1.2.1)

Copy Markdown View Source

Adapter for fetching remote content.

Use the fetch_remote!/2 for creating your own adapters if the default adapter is inappropriate for your use case.

Note that this module also contains overall logic for managing remote schemas.

Summary

Functions

uses the Req library to fetch remote content.

Functions

fetch_remote!(resource, opts)

@spec fetch_remote!(
  URI.t(),
  keyword()
) :: {encoded_json :: String.t(), content_type :: String.t() | nil}

uses the Req library to fetch remote content.

Note that this function fails if the remote resource does not return 200, and raises for any connection errors.