Module which provides a macro that generates special code for a relative json pointer filter.
the format is governed by this proposal: https://datatracker.ietf.org/doc/html/draft-handrews-relative-json-pointer-01
Summary
Functions
Creates a NimbleParsec parser ~relative-json-pointer/1.
Functions
Creates a NimbleParsec parser ~relative-json-pointer/1.
This function returns {:ok, ...} if the passed string is a valid relative
json pointer, or {:error, reason, ...} if it is not. See NimbleParsec for
more information on the return tuples.
The function will only be created once per module, and it is safe to call the macro more than once.
Options:
:name(atom): the name of the function to create. Defaults to:"~relative-json-pointer"