Module which provides a macro that generates special code for a uri template.
the format is governed by RFC 6570: https://www.rfc-editor.org/rfc/rfc6570.txt
Summary
Functions
Creates a NimbleParsec parser ~uri-template/1.
Functions
Creates a NimbleParsec parser ~uri-template/1.
This function returns {:ok, ...} if the passed string is a valid uri
template, or {:error, reason, ...} if it is not. See NimbleParsec for
more information on the return tuples.
The function will only be created once per module, and it is safe to call the macro more than once.
Options:
:name(atom): the name of the function to create. Defaults to:"~uri-template"