Adapter for fetching remote content.
Use the fetch_remote!/2 for creating your own adapters if the default
adapter is inappropriate for your use case.
Note that this module also contains overall logic for managing remote schemas.
Adapter for fetching remote content.
Use the fetch_remote!/2 for creating your own adapters if the default
adapter is inappropriate for your use case.
Note that this module also contains overall logic for managing remote schemas.